@@ -1,28 +1,28 @@
 /*
   Copyright (C)
- 
+
   2001: Macadamian Technologies Inc (author: Jian Huang, jian@macadamian.com)
   2003: Georg Robbers <Georg.Robbers@urz.uni-hd.de>
- 
+
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.
- 
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- 
+
 */
 
 #include "ark_part.h"
-#include "arksettings.h"
 #include "arkfactory.h"
+#include "settings.h"
 
 #include <kdebug.h>
 #include <kpopupmenu.h>
@@ -59,7 +59,7 @@ ArkPart::ArkPart( QWidget *parentWidget, const char * /*widgetName*/, QObject *p
                   const char *name, const QStringList &, bool readWrite )
         : KParts::ReadWritePart(parent, name)
 {
-    kdDebug()<<"ArkPart::ArkPart"<<endl;
+    kdDebug(1601)<<"ArkPart::ArkPart"<<endl;
     setInstance(ArkFactory::instance());
     awidget = new  ArkWidget( parentWidget, "ArkWidget" );
 
@@ -141,8 +141,19 @@ ArkPart::setupActions()
                                         SLOT(edit_invertSel()), actionCollection(), "invert_selection");
 
     saveAsAction = KStdAction::saveAs(this, SLOT(file_save_as()), actionCollection());
+    
+    //KStdAction::preferences(awidget, SLOT(showSettings()), actionCollection());
+
     ( void ) new KAction( i18n( "Configure &Ark..." ), "configure" , 0, awidget,
-                                        SLOT( options_dirs() ), actionCollection(), "options_configure_ark" );
+                                       SLOT( showSettings() ), actionCollection(), "options_configure_ark" );
+
+
+    showSearchBar = new KToggleAction( i18n( "Show Search Bar" ), KShortcut(), actionCollection(), "options_show_search_bar" );
+    showSearchBar->setCheckedState(i18n("Hide Search Bar"));
+
+    showSearchBar->setChecked( Settings::showSearchBar() );
+
+    connect( showSearchBar, SIGNAL( toggled( bool ) ), awidget, SLOT( slotShowSearchBarToggled( bool ) ) );
 
     initialEnables();
 }
@@ -166,6 +177,10 @@ void ArkPart::fixEnables()
     selectAllAction->setEnabled(bHaveFiles);
     deselectAllAction->setEnabled(bHaveFiles);
     invertSelectionAction->setEnabled(bHaveFiles);
+    if ( awidget->archive() )
+        shellOutputAction->setEnabled(true);
+    else
+        shellOutputAction->setEnabled(false);
 
     deleteAction->setEnabled(bHaveFiles && awidget->numSelectedFiles() > 0
                              && awidget->archive() && !bReadOnly);
@@ -178,7 +193,7 @@ void ArkPart::fixEnables()
     bool b = ( bHaveFiles && awidget->numSelectedFiles() == 1 );
     viewAction->setEnabled( b );
     openWithAction->setEnabled( b );
-    editAction->setEnabled( b );
+    editAction->setEnabled( b && !bReadOnly ); // You can't edit files in read-only archives
     emit fixActionState( bHaveFiles );
 }
 
@@ -198,6 +213,7 @@ void ArkPart::initialEnables()
     addDirAction->setEnabled(false);
     openWithAction->setEnabled(false);
     editAction->setEnabled(false);
+    shellOutputAction->setEnabled(false);
 }
 
 void ArkPart::disableActions()
@@ -215,6 +231,7 @@ void ArkPart::disableActions()
     addDirAction->setEnabled(false);
     openWithAction->setEnabled(false);
     editAction->setEnabled(false);
+    shellOutputAction->setEnabled(false);
 
 }
 
@@ -268,10 +285,10 @@ bool ArkPart::closeArchive()
 
 bool ArkPart::closeURL()
 {
-  if ( !isReadWrite() || !awidget->isModified() || url().isLocalFile() )
+  if ( !isReadWrite() || !awidget->isModified() || awidget->realURL().isLocalFile() )
     return closeArchive();
 
-  QString docName = url().prettyURL();
+  QString docName = awidget->realURL().prettyURL();
 
   int res = KMessageBox::warningYesNoCancel( widget(),
           i18n( "The archive \"%1\" has been modified.\n"
@@ -281,7 +298,7 @@ bool ArkPart::closeURL()
   switch ( res )
   {
     case KMessageBox::Yes :
-        return awidget->file_save_as( url() ) && closeArchive();
+        return awidget->file_save_as( awidget->realURL() ) && closeArchive();
 
     case KMessageBox::No :
         return closeArchive();
@@ -293,14 +310,8 @@ bool ArkPart::closeURL()
 
 void ArkPart::slotFilePopup( const QPoint &pPoint )
 {
-    static_cast<KPopupMenu *>(factory()->container("file_popup", this))->popup(pPoint);
-}
-
-void ArkPart::slotSaveProperties()
-{
-    awidget->settings()->writeConfiguration();
-
-    kdDebug(1601) << "-saveProperties (exit)" << endl;
+    if ( factory() )
+        static_cast<KPopupMenu *>(factory()->container("file_popup", this))->popup(pPoint);
 }
 
 ArkBrowserExtension::ArkBrowserExtension( KParts::ReadOnlyPart * parent, const char * name )
@@ -325,32 +336,26 @@ ArkStatusBarExtension::ArkStatusBarExtension( KParts::ReadWritePart * parent )
 
 ArkStatusBarExtension::~ArkStatusBarExtension()
 {
-    if ( m_bBusy )
-    {
-        removeStatusBarItem( m_pBusyText );
-        removeStatusBarItem( m_pProgressBar );
-    }
-    else if ( m_pStatusLabelSelect )
-    {
-        removeStatusBarItem( m_pStatusLabelSelect );
-        removeStatusBarItem( m_pStatusLabelTotal );
-    }
 }
 
 void ArkStatusBarExtension::setupStatusBar()
 {
-    if ( m_pTimer ) // setup already done
+    if ( m_pTimer                      // setup already done
+         || !statusBar() )
+    {
         return;
+    }
+
     m_pTimer = new QTimer( this );
     connect( m_pTimer, SIGNAL( timeout() ), this, SLOT( slotProgress() ) );
 
     m_pStatusLabelTotal = new QLabel( statusBar() );
-    m_pStatusLabelTotal->setFrameStyle( QFrame::Panel | QFrame::Raised );
+    m_pStatusLabelTotal->setFrameStyle( QFrame::NoFrame );
     m_pStatusLabelTotal->setAlignment( AlignRight );
     m_pStatusLabelTotal->setText( i18n( "Total: 0 files" ) );
 
     m_pStatusLabelSelect = new QLabel( statusBar() );
-    m_pStatusLabelSelect->setFrameStyle( QFrame::Panel | QFrame::Raised );
+    m_pStatusLabelSelect->setFrameStyle( QFrame::NoFrame );
     m_pStatusLabelSelect->setAlignment( AlignLeft );
     m_pStatusLabelSelect->setText(i18n( "0 files selected" ) );
 
@@ -360,19 +365,26 @@ void ArkStatusBarExtension::setupStatusBar()
 
 void ArkStatusBarExtension::slotSetStatusBarText( const QString & text )
 {
+    if ( !statusBar() )
+        return;
+
     setupStatusBar();
     m_pStatusLabelTotal->setText( text );
 }
 
 void ArkStatusBarExtension::slotSetStatusBarSelectedFiles( const QString & text )
 {
+
+    if ( !statusBar() )
+        return;
+
     setupStatusBar();
     m_pStatusLabelSelect->setText( text );
 }
 
 void ArkStatusBarExtension::slotSetBusy( const QString & text )
 {
-    if ( m_bBusy )
+    if ( m_bBusy || !statusBar() )
         return;
 
     setupStatusBar();
@@ -406,7 +418,7 @@ void ArkStatusBarExtension::slotSetBusy( const QString & text )
 
 void ArkStatusBarExtension::slotSetReady()
 {
-    if ( !m_bBusy )
+    if ( !m_bBusy || !statusBar() )
         return;
 
     setupStatusBar();
@@ -424,6 +436,9 @@ void ArkStatusBarExtension::slotSetReady()
 
 void ArkStatusBarExtension::slotProgress()
 {
+    if ( !statusBar() )
+        return;
+
     setupStatusBar();
     m_pProgressBar->setProgress( m_pProgressBar->progress() + 4 );
 }
