@@ -1680,6 +1680,10 @@ ArkWidget::action_extract()
     {
         dlg->disableSelectedFilesOption();
     }
+    else if (  m_nNumSelectedFiles > 1 )
+    {
+        dlg->setDefaultExtractOp(  ExtractDlg::Selected );
+    }
     if (archiveContent->currentItem() == NULL)
     {
         dlg->disableCurrentFileOption();
@@ -2307,13 +2311,14 @@ Arch * ArkWidget::getNewArchive( const QString & _fileName )
 {
     Arch * newArch = 0;
 
-    QString type = KMimeType::findByURL( _fileName )->name();
+    QString type = KMimeType::findByURL( KURL::fromPathOrURL(_fileName) )->name();
     ArchType archtype = ArchiveFormatInfo::self()->archTypeForMimeType(type);
     kdDebug( 1601 ) << "archtype is recognised as: " << archtype << endl;
     if(0 == (newArch = Arch::archFactory(archtype, this,
                                          _fileName)))
     {
         KMessageBox::error(this, i18n("Unknown archive format or corrupted archive") );
+        emit request_file_quit();
         return NULL;
     }
 
