@@ -311,9 +311,10 @@ KCalculator::KCalculator(QWidget *parent, const char *name)
 	largeBtnLayout->addWidget(pbParenOpen, 1, 0);
 	largeBtnLayout->addWidget(pbParenClose, 1, 1);
 
-	largeBtnLayout->addWidget(pbMR, 2, 0);
+	largeBtnLayout->addWidget(pbMemRecall, 2, 0);
+	largeBtnLayout->addWidget(pbMemStore, 2, 1);
 
-	largeBtnLayout->addWidget(pbMPlusMinus, 3, 0);
+	largeBtnLayout->addWidget(pbMemPlusMinus, 3, 0);
 	largeBtnLayout->addWidget(pbPercent, 3, 1);
 
 	largeBtnLayout->addWidget(pbMC, 4, 0);
@@ -340,8 +341,9 @@ KCalculator::KCalculator(QWidget *parent, const char *name)
 	mFunctionButtonList.append(pbPower);
 
 	mMemButtonList.append(pbEE);
-	mMemButtonList.append(pbMR);
-	mMemButtonList.append(pbMPlusMinus);
+	mMemButtonList.append(pbMemRecall);
+	mMemButtonList.append(pbMemPlusMinus);
+	mMemButtonList.append(pbMemStore);
 	mMemButtonList.append(pbMC);
 	mMemButtonList.append(pbClear);
 	mMemButtonList.append(pbAC);
@@ -648,16 +650,29 @@ QWidget* KCalculator::setupNumericKeys(QWidget *parent)
 	thisLayout->addColSpacing(4,10);
 
 
-	pbMR = new KCalcButton("MR", mLargePage, "MemRecall-Button", i18n("Memory recall"));
+	pbMemRecall = new KCalcButton("MR", mLargePage, "MemRecall-Button", i18n("Memory recall"));
 	connect(this, SIGNAL(switchShowAccels(bool)),
-		pbMR, SLOT(slotSetAccelDisplayMode(bool)));
-	connect(pbMR, SIGNAL(clicked(void)), SLOT(slotMRclicked(void)));
-        pbMR->setDisabled(true); // At start, there is nothing in memory
+		pbMemRecall, SLOT(slotSetAccelDisplayMode(bool)));
+	connect(pbMemRecall, SIGNAL(clicked(void)),
+		SLOT(slotMemRecallclicked(void)));
+	pbMemRecall->setDisabled(true); // At start, there is nothing in memory
 
-	pbMPlusMinus = new KCalcButton("M" "\xb1", mLargePage, "MPlusMinus-Button");
+	pbMemPlusMinus = new KCalcButton(mLargePage, "MPlusMinus-Button");
+	pbMemPlusMinus->addMode(ModeNormal, "M+", i18n("Add display to memory"));
+	pbMemPlusMinus->addMode(ModeInverse, "M-", i18n("Subtract from memory"));
+	connect(this, SIGNAL(switchMode(ButtonModeFlags,bool)),
+		pbMemPlusMinus, SLOT(slotSetMode(ButtonModeFlags,bool)));
 	connect(this, SIGNAL(switchShowAccels(bool)),
-		pbMPlusMinus, SLOT(slotSetAccelDisplayMode(bool)));
-	connect(pbMPlusMinus,SIGNAL(clicked(void)),SLOT(slotMPlusMinusclicked(void)));
+		pbMemPlusMinus, SLOT(slotSetAccelDisplayMode(bool)));
+	connect(pbMemPlusMinus,SIGNAL(clicked(void)),
+		SLOT(slotMemPlusMinusclicked(void)));
+
+	pbMemStore = new KCalcButton("MS", mLargePage, "MemStore-Button",
+					i18n("Memory store"));
+	connect(this, SIGNAL(switchShowAccels(bool)),
+		pbMemStore, SLOT(slotSetAccelDisplayMode(bool)));
+	connect(pbMemStore, SIGNAL(clicked(void)), SLOT(slotMemStoreclicked(void)));
+
 
 	pbMC = new KCalcButton("MC", mLargePage, "MemClear-Button", i18n("Clear memory"));
 	connect(this, SIGNAL(switchShowAccels(bool)),
@@ -920,11 +935,16 @@ void KCalculator::setupStatisticKeys(QWidget *parent)
 	connect(tmp_pb, SIGNAL(clicked(void)), SLOT(slotStatMeanclicked(void)));
 
 	tmp_pb = new KCalcButton(parent, "Stat.StandardDeviation-Button");
-	tmp_pb->addMode(ModeNormal, "Std", i18n("Standard deviation"));
+	tmp_pb->addMode(ModeNormal, QString::fromUtf8("σ",-1) +  "<sub>N-1</sub>",
+			i18n("Sample standard deviation"), true);
+	tmp_pb->addMode(ModeInverse, QString::fromUtf8("σ",-1) +  "<sub>N</sub>",
+			i18n("Standard deviation"), true);
 	pbStat.insert("StandardDeviation", tmp_pb);
         mStatButtonList.append(tmp_pb);
 	connect(this, SIGNAL(switchShowAccels(bool)),
 		tmp_pb, SLOT(slotSetAccelDisplayMode(bool)));
+	connect(this, SIGNAL(switchMode(ButtonModeFlags,bool)),
+		tmp_pb, SLOT(slotSetMode(ButtonModeFlags,bool)));
 	connect(tmp_pb, SIGNAL(clicked(void)), SLOT(slotStatStdDevclicked(void)));
 
 	tmp_pb = new KCalcButton(parent, "Stat.DataInput-Button");
@@ -1268,7 +1288,7 @@ void KCalculator::slotHyptoggled(bool flag)
 
 
 
-void KCalculator::slotMRclicked(void)
+void KCalculator::slotMemRecallclicked(void)
 {
 	// temp. work-around
 	calc_display->sendEvent(KCalcDisplay::EventReset);
@@ -1277,6 +1297,16 @@ void KCalculator::slotMRclicked(void)
 	UpdateDisplay(false);
 }
 
+void KCalculator::slotMemStoreclicked(void)
+{
+	EnterEqual();
+
+	memory_num = calc_display->getAmount();
+	//calc_display->setStatusText(3, "M");
+	statusBar()->changeItem("M",3);
+	pbMemRecall->setEnabled(true);
+}
+
 void KCalculator::slotNumberclicked(int number_clicked)
 {
 	calc_display->EnterDigit(number_clicked);
@@ -1337,7 +1367,7 @@ void KCalculator::slotPlusMinusclicked(void)
 	}
 }
 
-void KCalculator::slotMPlusMinusclicked(void)
+void KCalculator::slotMemPlusMinusclicked(void)
 {
 	bool tmp_inverse = inverse; // store this, because next command deletes inverse
 	EnterEqual(); // finish calculation so far, to store result into MEM
@@ -1347,7 +1377,7 @@ void KCalculator::slotMPlusMinusclicked(void)
 
 	pbInv->setOn(false);
 	statusBar()->changeItem("M",3);
-        pbMR->setEnabled(true);
+	pbMemRecall->setEnabled(true);
 }
 
 void KCalculator::slotCosclicked(void)
@@ -1516,7 +1546,7 @@ void KCalculator::slotMCclicked(void)
 {
 	memory_num		= 0;
 	statusBar()->changeItem(" \xa0\xa0 ",3);
-        pbMR->setDisabled(true);
+        pbMemRecall->setDisabled(true);
 }
 
 void KCalculator::slotClearclicked(void)
@@ -1694,15 +1724,15 @@ void KCalculator::slotStatMeanclicked(void)
 
 void KCalculator::slotStatStdDevclicked(void)
 {
-	if(!inverse)
+	if(inverse)
 	{
 		// std (n-1)
 		core.StatStdDeviation(0);
+		pbInv->setOn(false);
 	}
 	else
 	{
 		// std (n)
-		pbInv->setOn(false);
 		core.StatStdSample(0);
 	}
 
@@ -2277,14 +2307,14 @@ extern "C" KDE_EXPORT int kdemain(int argc, char *argv[])
                                     "(c) 2000-2003, The KDE Team"),
                           precisionStatement.latin1());
 
+	/* Klaus Niederkrueger */
+	aboutData.addAuthor("Klaus Niederkr" "\xc3\xbc" "ger", 0, "kniederk@math.uni-koeln.de");
 	aboutData.addAuthor("Bernd Johannes Wuebben", 0, "wuebben@kde.org");
-	aboutData.addAuthor("Evan Teran", 0, "emt3734@rit.edu");
+	aboutData.addAuthor("Evan Teran", 0, "eteran@alum.rit.edu");
 	aboutData.addAuthor("Espen Sand", 0, "espen@kde.org");
 	aboutData.addAuthor("Chris Howells", 0, "howells@kde.org");
 	aboutData.addAuthor("Aaron J. Seigo", 0, "aseigo@olympusproject.org");
 	aboutData.addAuthor("Charles Samuels", 0, "charles@altair.dhs.org");
-	/* Klaus Niederkrueger */
-	aboutData.addAuthor("Klaus Niederkr" "\xc3\xbc" "ger", 0, "kniederk@math.uni-koeln.de");
 	/* Rene Merou */
 	aboutData.addAuthor("Ren" "\xc3\xa9" " M" "\xc3\xa9"  "rou", 0, "ochominutosdearco@yahoo.es");
 	KCmdLineArgs::init(argc, argv, &aboutData);
