@@ -17,18 +17,14 @@
 
 #include <stdlib.h>
 
-#include <klocale.h>
 #include <qfile.h>
-
 #include <qcheckbox.h>
-
 #include <kapplication.h>
 #include <kiconloader.h>
 #include <kcombobox.h>
 #include <kdialogbase.h>
 #include <kmessagebox.h>
 #include <qtextcodec.h>
-#include "keyservers.h"
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qdialog.h>
@@ -37,22 +33,32 @@
 #include <qhbuttongroup.h>
 #include <qvbuttongroup.h>
 #include <qregexp.h>
+#include <qcursor.h>
+
+#include <klocale.h>
 #include <kprocess.h>
 #include <kprocio.h>
 #include <klistview.h>
 #include <kstatusbar.h>
 #include <kconfig.h>
 #include <klineedit.h>
+#include <ksimpleconfig.h>
+#include <kaction.h>
+#include <kdebug.h>
+
 
 #include "kgpgsettings.h"
+#include "searchres.h"
+#include "detailedconsole.h"
+#include "keyservers.h"
 
-keyServer::keyServer(QWidget *parent, const char *name,bool modal):KDialogBase( Swallow, i18n("Key Server"), Close, Close, parent, name,modal)
+keyServer::keyServer(QWidget *parent, const char *name,bool modal,bool autoClose):KDialogBase( Swallow, i18n("Key Server"), Close, Close, parent, name,modal)
 {
-        config=kapp->config();
-
+	autoCloseWindow=autoClose;
+	config=new KSimpleConfig ("kgpgrc");
 	page=new keyServerWidget();
 	setMainWidget(page);
-	
+
         syncCombobox();
         page->kLEimportid->setFocus();
 
@@ -65,12 +71,12 @@ keyServer::keyServer(QWidget *parent, const char *name,bool modal):KDialogBase(
         connect(page->cBproxyE,SIGNAL(toggled(bool)),this,SLOT(slotEnableProxyE(bool)));
 
         connect(page->kLEimportid,  SIGNAL( textChanged ( const QString & )), this,  SLOT( slotTextChanged( const QString &)));
+	page->cBproxyI->setChecked(KGpgSettings::useProxy());
+        page->cBproxyE->setChecked(KGpgSettings::useProxy());
         const char *httpproxy = getenv("http_proxy");
         if (httpproxy) {
                 page->cBproxyI->setEnabled(true);
                 page->cBproxyE->setEnabled(true);
-                page->cBproxyI->setChecked(true);
-                page->cBproxyE->setChecked(true);
                 page->kLEproxyI->setText(httpproxy);
                 page->kLEproxyE->setText(httpproxy);
         }
@@ -159,15 +165,16 @@ void keyServer::slotSearch()
         }
 
         //listpop = new KeyServer( this,"result",WType_Dialog | WShowModal);
-	
-	dialogServer=new KDialogBase(KDialogBase::Swallow, i18n("Key Properties"),  KDialogBase::Ok | KDialogBase::Close,KDialogBase::Ok,this,0,true);
-	
+
+	dialogServer=new KDialogBase(KDialogBase::Swallow, i18n("Import Key From Keyserver"),  KDialogBase::Ok | KDialogBase::Close,KDialogBase::Ok,this,0,true);
+
 	dialogServer->setButtonText(KDialogBase::Ok,i18n("&Import"));
+	dialogServer->enableButtonOK(false);
 	listpop=new searchRes();
         //listpop->setMinimumWidth(250);
         //listpop->adjustSize();
-        listpop->statusText->setText(i18n("Connecting to the server..."));   
-        
+        listpop->statusText->setText(i18n("Connecting to the server..."));
+
         connect(listpop->kLVsearch,SIGNAL(selectionChanged()),this,SLOT(transferKeyID()));
         connect(dialogServer,SIGNAL(okClicked()),this,SLOT(preimport()));
         connect(listpop->kLVsearch,SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),dialogServer,SIGNAL(okClicked()));
@@ -178,7 +185,7 @@ void keyServer::slotSearch()
         count=0;
         cycle=false;
         readmessage=QString::null;
-        KProcIO *searchproc=new KProcIO();
+        searchproc=new KProcIO();
         QString keyserv=page->kCBimportks->currentText();
         *searchproc<<"gpg";
         if (page->cBproxyI->isChecked()) {
@@ -192,7 +199,7 @@ void keyServer::slotSearch()
         QObject::connect(searchproc, SIGNAL(processExited(KProcess *)),this, SLOT(slotsearchresult(KProcess *)));
         QObject::connect(searchproc, SIGNAL(readReady(KProcIO *)),this, SLOT(slotsearchread(KProcIO *)));
         searchproc->start(KProcess::NotifyOnExit,true);
-	
+	QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
 	dialogServer->setMainWidget(listpop);
 	listpop->setMinimumSize(listpop->sizeHint());
         dialogServer->exec();
@@ -200,7 +207,13 @@ void keyServer::slotSearch()
 
 void keyServer::handleQuit()
 {
-        dialogServer->close();
+	if (searchproc->isRunning())
+	{
+	    QApplication::restoreOverrideCursor();
+	    disconnect(searchproc,0,0,0);
+	    searchproc->kill();
+	}
+	dialogServer->close();
 }
 
 
@@ -228,20 +241,33 @@ void keyServer::transferKeyID()
 {
         if (!listpop->kLVsearch->firstChild())
                 return;
-        QString kid;
-        if (listpop->kLVsearch->currentItem()->depth()==0)
-                kid=listpop->kLVsearch->currentItem()->firstChild()->text(0).stripWhiteSpace();
-        else
-                kid=listpop->kLVsearch->currentItem()->text(0).stripWhiteSpace();
-        kid=kid.section("key",1,1);
-        kid=kid.stripWhiteSpace();
-        kid=kid.left(8);
-        listpop->kLEID->setText(kid);
+        QString kid,keysToSearch;
+	listpop->kLEID->clear();
+	QPtrList< QListViewItem >searchList=listpop->kLVsearch->selectedItems();
+
+	for ( uint i = 0; i < searchList.count(); ++i )
+	{
+                if ( searchList.at(i) )
+		{
+                    if (searchList.at(i)->depth()==0)
+                	kid=searchList.at(i)->firstChild()->text(0).stripWhiteSpace();
+        		else
+                	kid=searchList.at(i)->text(0).stripWhiteSpace();
+		//
+        	kid=kid.section("key",1,1);
+        	kid=kid.stripWhiteSpace();
+		keysToSearch.append(" "+kid.left(8));
+		}
+	}
+	kdDebug(2100)<<keysToSearch<<endl;
+	listpop->kLEID->setText(keysToSearch.stripWhiteSpace());
 }
 
 void keyServer::slotsearchresult(KProcess *)
 {
         QString nb;
+	dialogServer->enableButtonOK(true);
+	QApplication::restoreOverrideCursor();
         nb=nb.setNum(keyNumbers);
         //listpop->kLVsearch->setColumnText(0,i18n("Found %1 matching keys").arg(nb));
         listpop->statusText->setText(i18n("Found %1 matching keys").arg(nb));
@@ -310,7 +336,7 @@ void keyServer::slotExport(QString keyId)
         *exportproc<<"gpg";
 	if (!page->exportAttributes->isChecked())
                 *exportproc<<"--export-options"<<"no-include-attributes";
-	
+
         if (page->cBproxyE->isChecked()) {
                 exportproc->setEnvironment("http_proxy",page->kLEproxyE->text());
                 *exportproc<<	"--keyserver-options"<<"honor-http-proxy";
@@ -321,8 +347,8 @@ void keyServer::slotExport(QString keyId)
         QObject::connect(exportproc, SIGNAL(processExited(KProcess *)),this, SLOT(slotexportresult(KProcess *)));
         QObject::connect(exportproc, SIGNAL(readReady(KProcIO *)),this, SLOT(slotimportread(KProcIO *)));
         exportproc->start(KProcess::NotifyOnExit,true);
-
-        importpop = new QDialog( this,0,true);
+	QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
+        importpop = new QDialog( this,0,true,Qt::WDestructiveClose);
         QVBoxLayout *vbox=new QVBoxLayout(importpop,3);
         QLabel *tex=new QLabel(importpop);
         tex->setText(i18n("<b>Connecting to the server...</b>"));
@@ -332,19 +358,23 @@ void keyServer::slotExport(QString keyId)
         importpop->setMinimumWidth(250);
         importpop->adjustSize();
         importpop->show();
-        connect(Buttonabort,SIGNAL(clicked ()),this,SLOT(abortExport()));
+        connect(importpop,SIGNAL(destroyed ()),this,SLOT(abortExport()));
+	connect(Buttonabort,SIGNAL(clicked ()),importpop,SLOT(close()));
 }
 
 void keyServer::abortExport()
 {
-        if (importpop)
-                delete importpop;
-        if (exportproc)
-                delete exportproc;
+	QApplication::restoreOverrideCursor();
+        if (exportproc->isRunning())
+	{
+	    disconnect(exportproc,0,0,0);
+	    exportproc->kill();
+	}
 }
 
 void keyServer::slotexportresult(KProcess*)
 {
+	QApplication::restoreOverrideCursor();
         KMessageBox::information(0,readmessage);
         if (importpop)
                 delete importpop;
@@ -362,7 +392,7 @@ void keyServer::slotImport()
         readmessage=QString::null;
         importproc=new KProcIO();
         QString keyserv=page->kCBimportks->currentText();
-
+	
         *importproc<<"gpg";
         if (page->cBproxyI->isChecked()) {
                 importproc->setEnvironment("http_proxy",page->kLEproxyI->text());
@@ -381,12 +411,12 @@ void keyServer::slotImport()
                 *importproc<<QFile::encodeName(fkeyNames);
         }
 
-
         QObject::connect(importproc, SIGNAL(processExited(KProcess *)),this, SLOT(slotimportresult(KProcess *)));
         QObject::connect(importproc, SIGNAL(readReady(KProcIO *)),this, SLOT(slotimportread(KProcIO *)));
         importproc->start(KProcess::NotifyOnExit,true);
-
-        importpop = new QDialog( this,0,true);
+	importproc->closeWhenDone();
+	QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
+        importpop = new QDialog( this,0,true,Qt::WDestructiveClose);
         QVBoxLayout *vbox=new QVBoxLayout(importpop,3);
         QLabel *tex=new QLabel(importpop);
         tex->setText(i18n("<b>Connecting to the server...</b>"));
@@ -396,19 +426,25 @@ void keyServer::slotImport()
         importpop->setMinimumWidth(250);
         importpop->adjustSize();
         importpop->show();
-        connect(Buttonabort,SIGNAL(clicked()),this,SLOT(abortImport()));
+	connect(Buttonabort,SIGNAL(clicked()),importpop,SLOT(close()));
+	connect(importpop,SIGNAL(destroyed ()),this,SLOT(abortImport()));
 }
 
 void keyServer::abortImport()
 {
-        if (importpop)
-                delete importpop;
-        if (importproc)
-                delete importproc;
+	QApplication::restoreOverrideCursor();
+	if (importproc->isRunning())
+	{
+	    disconnect(importproc,0,0,0);
+	    importproc->kill();
+	    emit importFinished(QString::null);
+	}
+	if (autoCloseWindow) close();
 }
 
 void keyServer::slotimportresult(KProcess*)
 {
+	QApplication::restoreOverrideCursor();
         QString importedNb,importedNbSucess,importedNbProcess,resultMessage, parsedOutput,importedNbUnchanged,importedNbSig;
 	QString notImportesNbSec,importedNbMissing,importedNbRSA,importedNbUid,importedNbSub,importedNbRev,readNbSec;
 	QString importedNbSec,dupNbSec;
@@ -437,40 +473,48 @@ void keyServer::slotimportresult(KProcess*)
 		importedNbSec=importedNb.section(" ",10,10);
 		dupNbSec=importedNb.section(" ",11,11);
 		notImportesNbSec=importedNb.section(" ",12,12);
-                resultMessage=i18n("<qt>%1 key(s) processed.<br></qt>").arg(importedNbProcess);
+                resultMessage=i18n("<qt>%n key processed.<br></qt>","<qt>%n keys processed.<br></qt>",importedNbProcess.toULong());
 		if (importedNbUnchanged!="0")
-		resultMessage+=i18n("<qt>%1 key(s) unchanged.<br></qt>").arg(importedNbUnchanged);
+		resultMessage+=i18n("<qt>One key unchanged.<br></qt>","<qt>%n keys unchanged.<br></qt>",importedNbUnchanged.toULong());
 		if (importedNbSig!="0")
-		resultMessage+=i18n("<qt>%1 signature(s) imported.<br></qt>").arg(importedNbSig);
+		resultMessage+=i18n("<qt>One signature imported.<br></qt>","<qt>%n signatures imported.<br></qt>",importedNbSig.toULong());
 		if (importedNbMissing!="0")
-		resultMessage+=i18n("<qt>%1 key(s) without ID.<br></qt>").arg(importedNbMissing);
+		resultMessage+=i18n("<qt>One key without ID.<br></qt>","<qt>%n keys without ID.<br></qt>",importedNbMissing.toULong());
 		if (importedNbRSA!="0")
-		resultMessage+=i18n("<qt>%1 RSA key(s) imported.<br></qt>").arg(importedNbRSA);
+		resultMessage+=i18n("<qt>One RSA key imported.<br></qt>","<qt>%n RSA keys imported.<br></qt>",importedNbRSA.toULong());
 		if (importedNbUid!="0")
-		resultMessage+=i18n("<qt>%1 user ID(s) imported.<br></qt>").arg(importedNbUid);
+		resultMessage+=i18n("<qt>One user ID imported.<br></qt>","<qt>%n user IDs imported.<br></qt>",importedNbUid.toULong());
 		if (importedNbSub!="0")
-		resultMessage+=i18n("<qt>%1 subkey(s) imported.<br></qt>").arg(importedNbSub);
+		resultMessage+=i18n("<qt>One subkey imported.<br></qt>","<qt>%n subkeys imported.<br></qt>",importedNbSub.toULong());
 		if (importedNbRev!="0")
-		resultMessage+=i18n("<qt>%1 revocation certificate(s) imported.<br></qt>").arg(importedNbRev);
+		resultMessage+=i18n("<qt>One revocation certificate imported.<br></qt>","<qt>%n revocation certificates imported.<br></qt>",importedNbRev.toULong());
 		if (readNbSec!="0")
-		resultMessage+=i18n("<qt>%1 secret key(s) processed.<br></qt>").arg(readNbSec);
+		resultMessage+=i18n("<qt>One secret key processed.<br></qt>","<qt>%n secret keys processed.<br></qt>",readNbSec.toULong());
 		if (importedNbSec!="0")
-		resultMessage+=i18n("<qt><b>%1 secret key(s) imported.</b><br></qt>").arg(importedNbSec);
+		resultMessage+=i18n("<qt><b>One secret key imported.</b><br></qt>","<qt><b>%n secret keys imported.</b><br></qt>",importedNbSec.toULong());
 		if (dupNbSec!="0")
-		resultMessage+=i18n("<qt>%1 secret key(s) unchanged.<br></qt>").arg(dupNbSec);
+		resultMessage+=i18n("<qt>One secret key unchanged.<br></qt>","<qt>%n secret keys unchanged.<br></qt>",dupNbSec.toULong());
 		if (notImportesNbSec!="0")
-		resultMessage+=i18n("<qt>%1 secret key(s) not imported.<br></qt>").arg(notImportesNbSec);
+		resultMessage+=i18n("<qt>One secret key not imported.<br></qt>","<qt>%n secret keys not imported.<br></qt>",notImportesNbSec.toULong());
 		if (importedNbSucess!="0")
-		resultMessage+=i18n("<qt><b>%1 key(s) imported:</b><br></qt>").arg(importedNbSucess);
+		resultMessage+=i18n("<qt><b>One key imported:</b><br></qt>","<qt><b>%n keys imported:</b><br></qt>",importedNbSucess.toULong());
         } else
                 resultMessage=i18n("No key imported... \nCheck detailed log for more infos");
-        KDetailedInfo *m_box=new KDetailedInfo(0,"import_result",resultMessage,readmessage,importedKeys);
+
+	QString lastID=QString("0x"+importedKeys.last().section(" ",0,0).right(8));
+	if (!lastID.isEmpty())
+	{
+	//kdDebug(2100)<<"++++++++++imported key"<<lastID<<endl;
+	emit importFinished(lastID);
+	}
+
         if (importpop)
                 importpop->hide();
-	m_box->setMinimumWidth(300);
-        m_box->exec();
+	(void) new KDetailedInfo(0,"import_result",resultMessage,readmessage,importedKeys);
+
         if (importpop)
                 delete importpop;
+	if (autoCloseWindow) close();
 }
 
 void keyServer::slotimportread(KProcIO *p)
@@ -482,25 +526,22 @@ void keyServer::slotimportread(KProcIO *p)
 
 void keyServer::syncCombobox()
 {
-	QString servers;
-        config->setGroup("GPG Settings");
-        QString confPath=config->readPathEntry("gpg_config_path");
+        config->setGroup("Servers");
+        QString serverList=config->readEntry("Server_List");
 
         QString optionsServer=KgpgInterface::getGpgSetting("keyserver", KGpgSettings::gpgConfigPath());
-        if (optionsServer.isEmpty())
-		optionsServer="hkp://wwwkeys.pgp.net";
+
+	//if (optionsServer.isEmpty())
+	//	optionsServer="hkp://wwwkeys.pgp.net";
+	page->kCBexportks->clear();
+	page->kCBimportks->clear();
+
 	page->kCBexportks->insertItem(optionsServer);
         page->kCBimportks->insertItem(optionsServer);
-	servers= KGpgSettings::keyServer2();
-        if (!servers.isEmpty()) {
-                page->kCBexportks->insertItem(servers);
-                page->kCBimportks->insertItem(servers);
-        }
-	servers= KGpgSettings::keyServer3();
-        if (!servers.isEmpty()) {
-                page->kCBexportks->insertItem(servers);
-                page->kCBimportks->insertItem(servers);
-        }
+
+	page->kCBexportks->insertStringList(QStringList::split(",",serverList));
+	page->kCBimportks->insertStringList(QStringList::split(",",serverList));
+
 }
 
 void keyServer::slotOk()
