@@ -21,34 +21,25 @@
 #include <qlayout.h>
 #include <qtabwidget.h>
 #include <qlabel.h>
-#include <qvbox.h>
 #include <qfile.h>
 #include <kconfig.h>
 #include <kdeversion.h>
 #include <klocale.h>
 #include <kprocio.h>
-#include <qdialog.h>
 #include <qcheckbox.h>
 #include <qradiobutton.h>
-#include <qbuttongroup.h>
 #include <qpushbutton.h>
-#include <qhbuttongroup.h>
-#include <qvbuttongroup.h>
 #include <qfont.h>
 #include <kaction.h>
-#include <qcombobox.h>
 #include <kmessagebox.h>
 #include <klineedit.h>
-#include <ktoolbar.h>
 #include <kcombobox.h>
 #include <kurlrequester.h>
-#include <kdialogbase.h>
 #include <kiconloader.h>
 #include <kfiledialog.h>
 #include <kinputdialog.h>
 #include <kfontdialog.h>
 #include <kdesktopfile.h>
-#include <kmimetype.h>
 #include <kstandarddirs.h>
 #include <kcolorbutton.h>
 #include <stdlib.h>
@@ -73,8 +64,6 @@ kgpgOptions::kgpgOptions(QWidget *parent, const char *name)
  : KConfigDialog( parent, name, KGpgSettings::self())
 {
 	ks=new KSimpleConfig ("kgpgrc");
-	ks->setGroup("Editor");
-	startFont=ks->readFontEntry("Editor_Font");
 
 	defaultServerList="hkp://wwwkeys.eu.pgp.net ";
 	defaultServerList+=i18n("(Default)");
@@ -100,9 +89,9 @@ kdDebug(2100)<<"Adding pages"<<endl;
 	page6=new ServerConf();
 	page7=new MiscConf();
 	QBoxLayout *fontLayout=new QBoxLayout(page3->tabWidget3->page(1),QBoxLayout::TopToBottom,10);
-	kfc=new KFontChooser(page3->tabWidget3->page(1),0L,false,QStringList(),false);
+	kfc=new KFontChooser(page3->tabWidget3->page(1),"kcfg_Font",false,QStringList(),false);
 	fontLayout->addWidget(kfc);
-	kfc->setFont(startFont);
+
 	page7->shredInfo->setText(i18n( "<qt><p>You must be aware that <b>shredding is not secure</b> on all file systems, and that parts of the file may have been saved in a temporary file or in the spooler of your printer if you previously opened it in an editor or tried to print it. Only works on files (not on folders).</p></qt>"));
 	page7->groupShred->adjustSize();
 	pixkeySingle=KGlobal::iconLoader()->loadIcon("kgpg_key1",KIcon::Small,20);
@@ -129,7 +118,6 @@ kdDebug(2100)<<"Adding pages"<<endl;
 	connect(page6->server_default, SIGNAL(clicked()), this, SLOT(slotDefaultKeyServer()));
 	connect(page6->ServerBox, SIGNAL(currentChanged ( QListBoxItem *)), this, SLOT(updateButtons()));
 	connect(page7->pushShredder, SIGNAL(clicked ()), this, SIGNAL(installShredder()));
-	connect(kfc, SIGNAL(fontSelected(const QFont &)), this, SLOT(updateButtons()));
 
 	keyGood=KGpgSettings::colorGood();
 	keyUnknown=KGpgSettings::colorUnknown();
@@ -211,7 +199,6 @@ void kgpgOptions::updateWidgets()
         if (keyServer.isEmpty())
 		keyServer = defaultKeyServer;
 
-        kfc->setFont(startFont);
 	
 	page6->ServerBox->clear();
 	page6->ServerBox->insertStringList(serverList);
@@ -224,12 +211,7 @@ void kgpgOptions::updateWidgetsDefault()
 {
         page1->encrypt_to_always->setChecked( defaultEncryptToAlways );
 
- 
-
-        page4->use_agent->setChecked( defaultUseAgent );
-	
-	kfc->setFont(QFont());
-	
+        page4->use_agent->setChecked( defaultUseAgent );	
 	
 	page4->gpg_conf_path->setText(defaultConfigPath);
 	page4->gpg_home_path->setText(defaultHomePath);
@@ -252,11 +234,7 @@ bool kgpgOptions::isDefault()
 		return false;
 
 	if (page4->use_agent->isChecked() != defaultUseAgent)
-		return false;
-	   
-	if (kfc->font()!=QFont())
-		return false;
-		
+		return false;		
 
 	QString currList;
 	for (uint i=0;i<page6->ServerBox->count();i++)
@@ -293,9 +271,6 @@ bool kgpgOptions::hasChanged()
 	currList.append(page6->ServerBox->text(i));
 	
 	if (currList!=serverList) return true;
-
-	if (kfc->font()!=startFont)
-		return true;
 	return false;
 }
 
@@ -332,15 +307,8 @@ void kgpgOptions::updateSettings()
 	
 	//////////////////  save key servers
 	
-	if (kfc->font()!=startFont)
-	{
-	emit changeFont(kfc->font());
-	startFont=kfc->font();
-	ks->setGroup("Editor");
-	ks->writeEntry("Editor_Font",startFont);
-	}
-	
 
+	emit changeFont(kfc->font());
         ///////////////  install service menus
 
         if (page7->kcfg_SignMenu->currentItem()==KGpgSettings::EnumSignMenu::AllFiles)
