@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -178,7 +178,7 @@ void CExportDialog::setupDestinationPage( void )
   label = new QLabel( text, page );
   hbox->addWidget( label );
  
-  text = i18n("(Package directory)"); 
+  text = i18n("(Package folder)"); 
   mDestination.fileExtraLabel = new QLabel( text, page );
   hbox->addWidget( mDestination.fileExtraLabel, 10, AlignLeft|AlignVCenter );
 
@@ -647,7 +647,7 @@ bool CExportDialog::verifyPackage( const QString &path )
     if( directory.mkdir( path ) == false )
     {
       QString msg;
-      msg += i18n("Unable to create new a new directory");
+      msg += i18n("Unable to create a new folder");
       msg += "\n";
       msg += path;
       KMessageBox::sorry( this, msg, title );
@@ -667,7 +667,7 @@ bool CExportDialog::verifyPackage( const QString &path )
       if( info.isWritable() == false ) 
       {
 	QString msg = i18n( ""
-          "You do not have write permission to this directory.");
+          "You do not have write permission to this folder.");
 	KMessageBox::sorry( this, msg, title );
 	return( false );
       }
@@ -677,7 +677,7 @@ bool CExportDialog::verifyPackage( const QString &path )
       QString f2 = QString("%1%2.html").arg(prefix).arg("99999999");
 
       QString msg = i18n( ""
-        "You have specified an existing directory.\n"
+        "You have specified an existing folder.\n"
 	"If you continue, any existing file in the range "
 	"\"%1\" to \"%2\" can be lost.\n"
 	"Continue?").arg(f1).arg(f2);
