@@ -62,6 +62,9 @@ class KJotsMain : public KMainWindow
         QString currentTitle();
         QString currentBookmarkURL();
 
+    public:
+        void updateCaption();
+
     protected slots:
         void slotSetupInterface();
         bool createFolder();
@@ -93,6 +96,13 @@ class KJotsMain : public KMainWindow
         void writePageToHTML();
         void savePageToFile(bool plainText);
 
+        void nextBook();
+        void prevBook();
+        void nextPage();
+        void prevPage();
+        QListViewItem* findNextBookItem();
+        QListViewItem* findPrevBookItem();
+
         // handling page changes in the listview
         void showListviewContextenu(KListView* l, QListViewItem* i, const QPoint& p);
         void bookLinkClicked(const QString&);
