@@ -100,7 +100,7 @@ bool GenericMonitor::retrieveVolume()
 
 	if (kmix_error) // maybe the error occurred because kmix wasn't running
 	{
-		_interface->displayText(i18n("Starting kmix..."));
+		_interface->displayText(i18n("Starting KMix..."));
 		if (kapp->startServiceByDesktopName("kmix")==0) // trying to start kmix
 		{
 			// trying again
@@ -118,7 +118,7 @@ bool GenericMonitor::retrieveVolume()
 	{
 		kdDebug() << "KMilo: GenericMonitor could not access kmix/Mixer0 via dcop" 
 							<< endl;
-		_interface->displayText(i18n("It seems that kmix is not running."));
+		_interface->displayText(i18n("It seems that KMix is not running."));
 		
 		return false;
 	} else {
@@ -131,6 +131,8 @@ void GenericMonitor::volumeUp(int step)
 	if (!retrieveVolume())
 		return;
 
+	// FIXME if the mixer doesn't support steps of the specified size it
+	// could get stuck at one position
 	m_volume += step;
 	if (m_volume > m_maxVolume)
 		m_volume = m_maxVolume;
@@ -184,7 +186,7 @@ bool GenericMonitor::retrieveMute()
 	if (kmix_error)
 	{
 		// maybe the error occurred because kmix wasn't running
-		_interface->displayText(i18n("Starting kmix..."));
+		_interface->displayText(i18n("Starting KMix..."));
 		if (kapp->startServiceByDesktopName("kmix")==0) // trying to start kmix
 		{
 			// trying again
@@ -206,7 +208,7 @@ bool GenericMonitor::retrieveMute()
 	{
 		kdDebug() << "KMilo: GenericMonitor could not access kmix/Mixer0 via dcop" 
 							<< endl;
-		_interface->displayText(i18n("It seems that kmix is not running."));
+		_interface->displayText(i18n("It seems that KMix is not running."));
 		
 		return false;
 	} else {
